//
//  SCAdInfo.h
//  SCMobileSDK
//
//  Copyright © 2018 smartclip Holding AG. All rights reserved.
//

#import <Foundation/Foundation.h>

/// This class holds the advertisement information
@interface SCAdInfo : NSObject

///Advariant, depending on the current schedule and VAST manifest
typedef enum Variant {
    /*
     * Default value to indicate that there has no value been set.
     */
    VARIANT_UNDEFINED = -1,
    OPENER,
    COMMERCIAL,
    BUMPER,
    SPONSORED,
    CLOSER
} Variant;

///Type of event that is reported
typedef enum EventType {
    /**
     * Default value to indicate that there has no value been set.
    */
    EVENT_TYPE_UNDEFINED = -1,

    /**
     * Is fired when the user clicks on the ad.
     */
    ON_AD_CLICKED,

    /**
     * Is fired when requesting or parsing of the manifest failed, also when ad playback failed.
     * Check Event.errorCode (or Event.info.errorCode) and the IAB VAST 4.0 Error Codes Table
     * for details.
     */
    ON_AD_ERROR,

    /**
     * Is fired when a single ad has been stopped. _(!) Double‐check the attribute adVariant to find out
     * whether this is the last ad or see {@code ON_AD_SLOTCOMPLETE}.
     */
    ON_AD_FINISHED,

    /**
     * Is fired when the playback of a single ad has reached 25%.
     */
    ON_AD_FIRST_QUARTILE,

    /**
     * Is fired when the user‐visible phase of the ad has begun.
     */
    ON_AD_IMPRESSION,

    /**
     * Is fired when a VPAID ad changes its linearity.
     */
    ON_AD_LINEARITY_CHANGE,

    /**
     * Is fired when the ad manifest (VAST tag) has been loaded.
     */
    ON_AD_MANIFEST_LOADED,

    /**
     * Is fired when the playback of a single ad has reached 50%.
     */
    ON_AD_MID_POINT,

    /**
     * Is fired when the playback of a single ad has been paused.
     */
    ON_AD_PAUSED,

    /**
     * Is fired when the playback of a single ad has been finished and reached 100%.
     */
    ON_AD_PLAYBACK_FINISHED,

    /**
     * Is fired when the playback of a single ad has been started, 0%.
     */
    ON_AD_PLAYBACK_START,

    /**
     * Is fired when the playback of a single ad has been resumed.
     */
    ON_AD_PLAYING,

    /**
     * Is fired when an ad manifest (VAST tag) was parsed and the ads have been added onto the
     * queue.
     */
    ON_AD_SCHEDULED,

    /**
     * Is fired when an ad has been skipped.
     */
    ON_AD_SKIPPED,

    /**
     * Is fired when an ad‐break has been finished, regardless whether the requested ad
     * manifest contained valid ads or not.
     */
    ON_AD_SLOT_COMPLETE,

    /**
     * Is fired when the playback of all ads for the current ad‐break has finished, most likely
     * after the CLOSER.
     */
    ON_AD_SLOT_FINISHED,

    /**
     * Is fired when an ad‐break has been requested.
     */
    ON_AD_SLOT_START,

    /**
     * Is fired when the playback of the first ad for the current ad‐break has been started, most
     * likely the OPENER.
     */
    ON_AD_SLOT_STARTED,

    /**
     * Is fired when the playback of an ad has been started.
     */
    ON_AD_STARTED,

    /**
     * Is fired when the playback of a single ad has reached 75%.
     */
    ON_AD_THIRD_QUARTILE
} EventType;

///Event type
@property (nonatomic, readonly)       EventType           type;

///Always smartclip
@property (nonatomic, readonly, copy) NSString           *issuer;

///Adopted from the Bitmovin Player Events. Current client time
@property (nonatomic, readonly)       NSTimeInterval      timestamp;

///Number of the current ad, regardless of its variant
@property (nonatomic, readonly)       NSInteger           currentClip;

///Total number of ads within the current adbreak, regardless of variants
@property (nonatomic, readonly)       NSInteger           totalClips;

///Number of the current ad of variant COMMERCIAL.
@property (nonatomic, readonly)       NSInteger           currentCommercial;

///Total number of ads with variant COMMERCIAL within the current adbreak
@property (nonatomic, readonly)       NSInteger           totalCommercials;

///Total duration of ads with variant COMMERCIAL within the current adbreak
@property (nonatomic, readonly)       NSTimeInterval      totalCommercialsDuration;

///Current time of the content video in seconds
@property (nonatomic, readonly)       NSInteger           offset;

///Advariant, depending on the current schedule and VAST manifest.
///Possible values are OPENER, COMMERCIAL, BUMPER, SPONSORED and CLOSER
@property (nonatomic, readonly)       Variant             variant;

///Total time of the current ad
@property (nonatomic, readonly)       NSTimeInterval      duration;

///Value of the id attribute from the VAST > Adnode
@property (nonatomic, readonly, copy) NSString           *adId;

///Value of the VAST > Ad > AdTitle node
@property (nonatomic, readonly, copy) NSString           *title;

///Applies to VASTWrappers. VASTAdTagURI from the initial requested tag.
@property (nonatomic, readonly, copy) NSString           *vendorUrl;

///Applies to VASTWrappers. Array of Wrapperobjects, starting with the initial request up to the last Wrapper before the Inline tag
@property (nonatomic, readonly, copy) NSArray            *wrapperTags;

///Code according to IAB VAST4.0 Error Codes Table and custom Error Codes
@property (nonatomic, readonly)       NSInteger           errorCode;

///The Campaign identifier
@property (nonatomic, readonly, copy) NSString           *cid;

///The Goal identifier
@property (nonatomic, readonly, copy) NSString           *gid;

/// String representation of eventType
- (NSString*)eventString;

/// String representation of variant
- (NSString*)variantString;

/// String representation of the SCAdInfo object
- (NSString*)toString;
@end
